@@ -22,7 +22,7 @@
 #include "device.h"
 
 #include <QDBusConnection>
-#include <QtDBus/QtDBus>
+#include <QtDBus>
 
 Device::Device(QObject *parent)
     : QObject(parent)
@@ -153,6 +153,11 @@ QString Device::ipInterface() const
     return m_ipInterface;
 }
 
+uint Device::interfaceFlags() const
+{
+    return m_interfaceFlags;
+}
+
 bool Device::managed() const
 {
     return m_managed;
@@ -238,6 +243,11 @@ void Device::setInterface(const QString &interface)
     m_interface = interface;
 }
 
+void Device::setInterfaceFlags(uint interfaceFlags)
+{
+    m_interfaceFlags = interfaceFlags;
+}
+
 void Device::setIp4Config(const QString &config)
 {
     m_ip4Config = QDBusObjectPath(config);
